@@ -50,6 +50,7 @@
 #include <XdgDirs>
 
 #include <KWindowSystem/KWindowSystem>
+#include <KWindowSystem/KX11Extras>
 #include <KWindowSystem/NETWM>
 
 // Turn on this to show the time required to load each plugin during startup
@@ -241,18 +242,18 @@ LXQtPanel::LXQtPanel(const QString &configGroup, LXQt::Settings *settings, QWidg
         QTimer::singleShot(PANEL_HIDE_FIRST_TIME, this, SLOT(hidePanel()));
     }
 
-    connect(KWindowSystem::self(), &KWindowSystem::windowAdded, this, [this] {
+    connect(KX11Extras::self(), &KX11Extras::windowAdded, this, [this] {
         if (mHidable && mHideOnOverlap && !mHidden)
         {
             mShowDelayTimer.stop();
             hidePanel();
         }
     });
-    connect(KWindowSystem::self(), &KWindowSystem::windowRemoved, this, [this] {
+    connect(KX11Extras::self(), &KX11Extras::windowRemoved, this, [this] {
         if (mHidable && mHideOnOverlap && mHidden && !isPanelOverlapped())
             mShowDelayTimer.start();
     });
-    connect(KWindowSystem::self(), &KWindowSystem::currentDesktopChanged, this, [this] {
+    connect(KX11Extras::self(), &KX11Extras::currentDesktopChanged, this, [this] {
        if (mHidable && mHideOnOverlap)
        {
             if (!mHidden)
@@ -264,8 +265,8 @@ LXQtPanel::LXQtPanel(const QString &configGroup, LXQt::Settings *settings, QWidg
                 mShowDelayTimer.start();
        }
     });
-    connect(KWindowSystem::self(),
-            static_cast<void (KWindowSystem::*)(WId, NET::Properties, NET::Properties2)>(&KWindowSystem::windowChanged),
+    connect(KX11Extras::self(),
+            static_cast<void (KX11Extras::*)(WId, NET::Properties, NET::Properties2)>(&KX11Extras::windowChanged),
             this, [this] (WId /* id */, NET::Properties prop, NET::Properties2) {
         if (mHidable && mHideOnOverlap
             // when a window is moved, resized, shaded, or minimized
@@ -418,7 +419,7 @@ LXQtPanel::~LXQtPanel()
 void LXQtPanel::show()
 {
     QWidget::show();
-    KWindowSystem::setOnDesktop(effectiveWinId(), NET::OnAllDesktops);
+    KX11Extras::setOnDesktop(effectiveWinId(), NET::OnAllDesktops);
 }
 
 
@@ -675,7 +676,7 @@ void LXQtPanel::updateWmStrut()
         switch (mPosition)
         {
         case LXQtPanel::PositionTop:
-            KWindowSystem::setExtendedStrut(wid,
+            KX11Extras::setExtendedStrut(wid,
                                             /* Left   */  0, 0, 0,
                                             /* Right  */  0, 0, 0,
                                             /* Top    */  rect.top() + getReserveDimension(), rect.left(), rect.right(),
@@ -684,7 +685,7 @@ void LXQtPanel::updateWmStrut()
             break;
 
         case LXQtPanel::PositionBottom:
-            KWindowSystem::setExtendedStrut(wid,
+            KX11Extras::setExtendedStrut(wid,
                                             /* Left   */  0, 0, 0,
                                             /* Right  */  0, 0, 0,
                                             /* Top    */  0, 0, 0,
@@ -693,7 +694,7 @@ void LXQtPanel::updateWmStrut()
             break;
 
         case LXQtPanel::PositionLeft:
-            KWindowSystem::setExtendedStrut(wid,
+            KX11Extras::setExtendedStrut(wid,
                                             /* Left   */  rect.left() + getReserveDimension(), rect.top(), rect.bottom(),
                                             /* Right  */  0, 0, 0,
                                             /* Top    */  0, 0, 0,
@@ -703,7 +704,7 @@ void LXQtPanel::updateWmStrut()
             break;
 
         case LXQtPanel::PositionRight:
-            KWindowSystem::setExtendedStrut(wid,
+            KX11Extras::setExtendedStrut(wid,
                                             /* Left   */  0, 0, 0,
                                             /* Right  */  wholeScreen.right() - rect.right() + getReserveDimension(), rect.top(), rect.bottom(),
                                             /* Top    */  0, 0, 0,
@@ -713,7 +714,7 @@ void LXQtPanel::updateWmStrut()
     }
     } else
     {
-        KWindowSystem::setExtendedStrut(wid,
+        KX11Extras::setExtendedStrut(wid,
                                         /* Left   */  0, 0, 0,
                                         /* Right  */  0, 0, 0,
                                         /* Top    */  0, 0, 0,
@@ -825,8 +826,8 @@ void LXQtPanel::showConfigDialog()
     mConfigDialog->activateWindow();
     WId wid = mConfigDialog->windowHandle()->winId();
 
-    KWindowSystem::activateWindow(wid);
-    KWindowSystem::setOnDesktop(wid, KWindowSystem::currentDesktop());
+    KX11Extras::activateWindow(wid);
+    KX11Extras::setOnDesktop(wid, KX11Extras::currentDesktop());
 }
 
 
@@ -845,8 +846,8 @@ void LXQtPanel::showAddPluginDialog()
     mConfigDialog->activateWindow();
     WId wid = mConfigDialog->windowHandle()->winId();
 
-    KWindowSystem::activateWindow(wid);
-    KWindowSystem::setOnDesktop(wid, KWindowSystem::currentDesktop());
+    KX11Extras::activateWindow(wid);
+    KX11Extras::setOnDesktop(wid, KX11Extras::currentDesktop());
 }
 
 
@@ -1129,7 +1130,7 @@ bool LXQtPanel::event(QEvent *event)
         KWindowSystem::setType(effectiveWinId(), NET::Dock);
 
         updateWmStrut(); // reserve screen space for the panel
-        KWindowSystem::setOnAllDesktops(effectiveWinId(), true);
+        KX11Extras::setOnAllDesktops(effectiveWinId(), true);
         break;
     }
     case QEvent::DragEnter:
@@ -1413,7 +1414,7 @@ bool LXQtPanel::isPanelOverlapped() const
     ignoreList |= NET::TopMenuMask;
     ignoreList |= NET::NotificationMask;
 
-    const auto wIds = KWindowSystem::stackingOrder();
+    const auto wIds = KX11Extras::stackingOrder();
     for (auto const wId : wIds)
     {
         KWindowInfo info(wId, NET::WMWindowType | NET::WMState | NET::WMFrameExtents | NET::WMDesktop);
