@@ -4,7 +4,7 @@
 <context>
     <name>LXQtCustomCommand</name>
     <message>
-        <location filename="../lxqtcustomcommand.cpp" line="176"/>
+        <location filename="../lxqtcustomcommand.cpp" line="186"/>
         <source>Error</source>
         <translation>Error</translation>
     </message>
@@ -22,120 +22,125 @@
         <translation>Mostra</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="28"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="181"/>
         <source>Use icon from theme or browse file</source>
         <translation>Usa la icona del tema o navega fins al fitxer</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="35"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="188"/>
         <source>Run with &quot;bash -c&quot;</source>
         <translation>Executa amb &quot;bash -c&quot;</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="45"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="198"/>
         <source>Select Font</source>
         <translation>Selecciona la lletra tipogràfica</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="55"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="218"/>
         <source>Text</source>
         <translation>Text</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="65"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="135"/>
         <source>Command</source>
         <translation>Ordre</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="75"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="128"/>
         <source>Font</source>
         <translation>Lletra tipogràfica</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="82"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="162"/>
         <source> px</source>
         <translation> px</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="101"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="208"/>
         <source>%1</source>
         <translation>%1</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="104"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="211"/>
         <source>Use %1 to display command output</source>
         <translation>Usa % 1 per mostrar la sortida de l&apos;ordre</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="111"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="145"/>
         <source>Icon</source>
         <translation>Icona</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="121"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="108"/>
         <source>Browse</source>
         <translation>Navega</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="131"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="155"/>
         <source>Autorotate when the panel is vertical</source>
         <translation>Gira automàticament quan el panell sigui vertical</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="150"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="240"/>
         <source>echo Configure...</source>
         <translation>Configuració de l&apos;eco...</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="153"/>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="271"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="243"/>
         <location filename="../lxqtcustomcommandconfiguration.ui" line="278"/>
         <location filename="../lxqtcustomcommandconfiguration.ui" line="285"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="292"/>
         <source>Command to run</source>
         <translation>Ordre a executar</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="160"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="118"/>
         <source>Max Width</source>
         <translation>Amplada màxima</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="212"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="70"/>
         <source>Repeat command after:</source>
         <translation>Repeteix l&apos;ordre després de:</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="228"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="86"/>
         <source> second(s)</source>
         <translation> segon(s)</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="255"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="250"/>
+        <source>Command outputs an image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="262"/>
         <source>Mouse Commands</source>
         <translation>Ordres del ratolí</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="261"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="268"/>
         <source>Click</source>
         <translation>Clic</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="292"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="299"/>
         <source>Wheel Up</source>
         <translation>Roda amunt</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="302"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="309"/>
         <source>Wheel Down</source>
         <translation>Roda avall</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.cpp" line="139"/>
+        <location filename="../lxqtcustomcommandconfiguration.cpp" line="147"/>
         <source>Select Icon File</source>
         <translation>Trieu un fitxer d&apos;icona</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.cpp" line="139"/>
+        <location filename="../lxqtcustomcommandconfiguration.cpp" line="147"/>
         <source>Images (*.png *.svg *.xpm *.jpg)</source>
         <translation>Imatges (*.png *.svg *.xpm *.jpg)</translation>
     </message>
