@@ -4,7 +4,7 @@
 <context>
     <name>LXQtCustomCommand</name>
     <message>
-        <location filename="../lxqtcustomcommand.cpp" line="176"/>
+        <location filename="../lxqtcustomcommand.cpp" line="186"/>
         <source>Error</source>
         <translation>오류</translation>
     </message>
@@ -22,120 +22,125 @@
         <translation>디스플레이</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="28"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="181"/>
         <source>Use icon from theme or browse file</source>
         <translation>테마에서 아이콘 사용 또는 파일 찾아보기</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="35"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="188"/>
         <source>Run with &quot;bash -c&quot;</source>
         <translation>&quot;bash -c&quot;로 실행</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="45"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="198"/>
         <source>Select Font</source>
         <translation>글꼴 선택</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="55"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="218"/>
         <source>Text</source>
         <translation>텍스트</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="65"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="135"/>
         <source>Command</source>
         <translation>명령</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="75"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="128"/>
         <source>Font</source>
         <translation>글꼴</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="82"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="162"/>
         <source> px</source>
         <translation> 픽셀</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="101"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="208"/>
         <source>%1</source>
         <translation>%1</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="104"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="211"/>
         <source>Use %1 to display command output</source>
         <translation>명령 출력을 표시하려면 %1 사용</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="111"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="145"/>
         <source>Icon</source>
         <translation>아이콘</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="121"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="108"/>
         <source>Browse</source>
         <translation>찾아보기</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="131"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="155"/>
         <source>Autorotate when the panel is vertical</source>
         <translation>패널이 수직일 때 자동 회전</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="150"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="240"/>
         <source>echo Configure...</source>
         <translation>에코 구성하기...</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="153"/>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="271"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="243"/>
         <location filename="../lxqtcustomcommandconfiguration.ui" line="278"/>
         <location filename="../lxqtcustomcommandconfiguration.ui" line="285"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="292"/>
         <source>Command to run</source>
         <translation>실행할 명령</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="160"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="118"/>
         <source>Max Width</source>
         <translation>최대 너비</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="212"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="70"/>
         <source>Repeat command after:</source>
         <translation>다음 시간 이후에 명령 반복:</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="228"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="86"/>
         <source> second(s)</source>
         <translation> 초</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="255"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="250"/>
+        <source>Command outputs an image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="262"/>
         <source>Mouse Commands</source>
         <translation>마우스 명령</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="261"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="268"/>
         <source>Click</source>
         <translation>클릭</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="292"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="299"/>
         <source>Wheel Up</source>
         <translation>휠 위로</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="302"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="309"/>
         <source>Wheel Down</source>
         <translation>휠 아래로</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.cpp" line="139"/>
+        <location filename="../lxqtcustomcommandconfiguration.cpp" line="147"/>
         <source>Select Icon File</source>
         <translation>아이콘 파일 선택</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.cpp" line="139"/>
+        <location filename="../lxqtcustomcommandconfiguration.cpp" line="147"/>
         <source>Images (*.png *.svg *.xpm *.jpg)</source>
         <translation>이미지 (*.png *.svg *.xpm *.jpg)</translation>
     </message>
