@@ -4,7 +4,7 @@
 <context>
     <name>LXQtCustomCommand</name>
     <message>
-        <location filename="../lxqtcustomcommand.cpp" line="176"/>
+        <location filename="../lxqtcustomcommand.cpp" line="186"/>
         <source>Error</source>
         <translation>Chyba</translation>
     </message>
@@ -22,120 +22,125 @@
         <translation>Zobraziť</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="28"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="181"/>
         <source>Use icon from theme or browse file</source>
         <translation>Použiť ikonu z témy alebo prehliadať súbor</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="35"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="188"/>
         <source>Run with &quot;bash -c&quot;</source>
         <translation>Spustiť s &quot;bash -c&quot;</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="45"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="198"/>
         <source>Select Font</source>
         <translation>Vybrať písmo</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="55"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="218"/>
         <source>Text</source>
         <translation>Text</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="65"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="135"/>
         <source>Command</source>
         <translation>Príkaz</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="75"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="128"/>
         <source>Font</source>
         <translation>Písmo</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="82"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="162"/>
         <source> px</source>
         <translation> px</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="101"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="208"/>
         <source>%1</source>
         <translation>%1</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="104"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="211"/>
         <source>Use %1 to display command output</source>
         <translation>Použiť%1 na zobrazenie výstupu príkazu</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="111"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="145"/>
         <source>Icon</source>
         <translation>Ikona</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="121"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="108"/>
         <source>Browse</source>
         <translation>Prehliadať</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="131"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="155"/>
         <source>Autorotate when the panel is vertical</source>
         <translation>Automaticky otočiť v prípade, že je panel zvislý</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="150"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="240"/>
         <source>echo Configure...</source>
         <translation>echo Konfigurovať...</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="153"/>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="271"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="243"/>
         <location filename="../lxqtcustomcommandconfiguration.ui" line="278"/>
         <location filename="../lxqtcustomcommandconfiguration.ui" line="285"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="292"/>
         <source>Command to run</source>
         <translation>Príkaz na spustenie</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="160"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="118"/>
         <source>Max Width</source>
         <translation>Maximálna šírka</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="212"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="70"/>
         <source>Repeat command after:</source>
         <translation>Opakovať príkaz po:</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="228"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="86"/>
         <source> second(s)</source>
         <translation> Sekundy(s)</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="255"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="250"/>
+        <source>Command outputs an image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="262"/>
         <source>Mouse Commands</source>
         <translation>Príkaz myšou</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="261"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="268"/>
         <source>Click</source>
         <translation>Kliknutie</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="292"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="299"/>
         <source>Wheel Up</source>
         <translation>Koliesko hore</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="302"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="309"/>
         <source>Wheel Down</source>
         <translation>Koliesko dole</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.cpp" line="139"/>
+        <location filename="../lxqtcustomcommandconfiguration.cpp" line="147"/>
         <source>Select Icon File</source>
         <translation>Vybrať súbor ikôn</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.cpp" line="139"/>
+        <location filename="../lxqtcustomcommandconfiguration.cpp" line="147"/>
         <source>Images (*.png *.svg *.xpm *.jpg)</source>
         <translation>Obrázky (*.png *.svg *.xpm *.jpg)</translation>
     </message>
