@@ -4,7 +4,7 @@
 <context>
     <name>LXQtCustomCommand</name>
     <message>
-        <location filename="../lxqtcustomcommand.cpp" line="176"/>
+        <location filename="../lxqtcustomcommand.cpp" line="186"/>
         <source>Error</source>
         <translation>錯誤</translation>
     </message>
@@ -22,120 +22,125 @@
         <translation>顯示</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="28"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="181"/>
         <source>Use icon from theme or browse file</source>
         <translation>使用佈景主題提供的圖示或是瀏覽檔案</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="35"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="188"/>
         <source>Run with &quot;bash -c&quot;</source>
         <translation>以 &quot;bash -c&quot; 執行</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="45"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="198"/>
         <source>Select Font</source>
         <translation>選擇字型</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="55"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="218"/>
         <source>Text</source>
         <translation>顯示文字</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="65"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="135"/>
         <source>Command</source>
         <translation>指令</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="75"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="128"/>
         <source>Font</source>
         <translation>字體</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="82"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="162"/>
         <source> px</source>
         <translation> px</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="101"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="208"/>
         <source>%1</source>
         <translation>%1</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="104"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="211"/>
         <source>Use %1 to display command output</source>
         <translation>使用 %1 顯示指令的輸出</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="111"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="145"/>
         <source>Icon</source>
         <translation>圖示</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="121"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="108"/>
         <source>Browse</source>
         <translation>瀏覽</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="131"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="155"/>
         <source>Autorotate when the panel is vertical</source>
         <translation>當面板垂直時自動旋轉</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="150"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="240"/>
         <source>echo Configure...</source>
         <translation>echo 請設定…</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="153"/>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="271"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="243"/>
         <location filename="../lxqtcustomcommandconfiguration.ui" line="278"/>
         <location filename="../lxqtcustomcommandconfiguration.ui" line="285"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="292"/>
         <source>Command to run</source>
         <translation>要執行的指令</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="160"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="118"/>
         <source>Max Width</source>
         <translation>最大寬度</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="212"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="70"/>
         <source>Repeat command after:</source>
         <translation>經過這些時間後重複執行指令:</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="228"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="86"/>
         <source> second(s)</source>
         <translation> 秒</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="255"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="250"/>
+        <source>Command outputs an image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="262"/>
         <source>Mouse Commands</source>
         <translation>滑鼠指令</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="261"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="268"/>
         <source>Click</source>
         <translation>點擊</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="292"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="299"/>
         <source>Wheel Up</source>
         <translation>滾輪向上</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="302"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="309"/>
         <source>Wheel Down</source>
         <translation>滾輪向下</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.cpp" line="139"/>
+        <location filename="../lxqtcustomcommandconfiguration.cpp" line="147"/>
         <source>Select Icon File</source>
         <translation>選擇圖示檔</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.cpp" line="139"/>
+        <location filename="../lxqtcustomcommandconfiguration.cpp" line="147"/>
         <source>Images (*.png *.svg *.xpm *.jpg)</source>
         <translation>圖片 (*.png *.svg *.xpm *.jpg)</translation>
     </message>
