@@ -4,13 +4,13 @@
 <context>
     <name>DesktopSwitch</name>
     <message>
-        <location filename="../desktopswitch.cpp" line="87"/>
+        <location filename="../desktopswitch.cpp" line="88"/>
         <source>Switch to desktop %1</source>
         <translation>מעבר לשולחן עבודה %1</translation>
     </message>
     <message>
-        <location filename="../desktopswitch.cpp" line="148"/>
-        <location filename="../desktopswitch.cpp" line="159"/>
+        <location filename="../desktopswitch.cpp" line="149"/>
+        <location filename="../desktopswitch.cpp" line="160"/>
         <source>Desktop %1</source>
         <translation>שולחן עבודה %1</translation>
     </message>
@@ -73,4 +73,17 @@
         <translation>שולחן עבודה %1:</translation>
     </message>
 </context>
+<context>
+    <name>DesktopSwitchUnsupported</name>
+    <message>
+        <location filename="../desktopswitch.h" line="111"/>
+        <source>n/a</source>
+        <translation>לא זמין</translation>
+    </message>
+    <message>
+        <location filename="../desktopswitch.h" line="113"/>
+        <source>DesktopSwitch is unsupported on current platform: %1</source>
+        <translation>אין תמיכה במעבר שולחנות עבודה (DesktopSwitch) בפלטפורמה הנוכחית: %1</translation>
+    </message>
+</context>
 </TS>
