@@ -4,14 +4,14 @@
 <context>
     <name>DesktopSwitch</name>
     <message>
-        <location filename="../desktopswitch.cpp" line="87"/>
+        <location filename="../desktopswitch.cpp" line="88"/>
         <source>Switch to desktop %1</source>
         <translatorcomment>Перейти на стільницю %1 </translatorcomment>
         <translation>Перемкнутися до стільниці %1</translation>
     </message>
     <message>
-        <location filename="../desktopswitch.cpp" line="148"/>
-        <location filename="../desktopswitch.cpp" line="159"/>
+        <location filename="../desktopswitch.cpp" line="149"/>
+        <location filename="../desktopswitch.cpp" line="160"/>
         <source>Desktop %1</source>
         <translation>Стільниця %1</translation>
     </message>
@@ -74,4 +74,17 @@
         <translation>Стільниця %1:</translation>
     </message>
 </context>
+<context>
+    <name>DesktopSwitchUnsupported</name>
+    <message>
+        <location filename="../desktopswitch.h" line="111"/>
+        <source>n/a</source>
+        <translation>н/д</translation>
+    </message>
+    <message>
+        <location filename="../desktopswitch.h" line="113"/>
+        <source>DesktopSwitch is unsupported on current platform: %1</source>
+        <translation>DesktopSwitch не підтримується на цій платформі: %1</translation>
+    </message>
+</context>
 </TS>
