@@ -12,7 +12,7 @@
         <location filename="../treewindow.ui" line="63"/>
         <location filename="../treewindow.ui" line="96"/>
         <source>Property</source>
-        <translation>Vlastnictví</translation>
+        <translation>Vlastnost</translation>
     </message>
     <message>
         <location filename="../treewindow.ui" line="68"/>
