@@ -6,7 +6,7 @@
     <message>
         <location filename="../treewindow.ui" line="14"/>
         <source>Panel DOM tree</source>
-        <translation>DOM-boomstructuur voor werkbalk</translation>
+        <translation>DOM-boomweergave op paneel</translation>
     </message>
     <message>
         <location filename="../treewindow.ui" line="63"/>
