@@ -6,7 +6,7 @@
     <message>
         <location filename="../button.cpp" line="38"/>
         <source>Removable media/devices manager</source>
-        <translation type="unfinished">Менаџер уклоњивих медија/уређаја</translation>
+        <translation>Менаџер уклоњивих медија/уређаја</translation>
     </message>
 </context>
 <context>
@@ -14,48 +14,48 @@
     <message>
         <location filename="../configuration.ui" line="14"/>
         <source>Removable Media Settings</source>
-        <translation type="unfinished"></translation>
+        <translation>Подешавања уклоњивих медија</translation>
     </message>
     <message>
         <location filename="../configuration.ui" line="20"/>
         <source>Behaviour</source>
-        <translation type="unfinished">Понашање</translation>
+        <translation>Понашање</translation>
     </message>
     <message>
         <location filename="../configuration.ui" line="32"/>
         <source>When a device is connected:</source>
-        <translation type="unfinished"></translation>
+        <translation>Када је уређај повезан:</translation>
     </message>
     <message>
         <location filename="../configuration.ui" line="42"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Trigger the following action when eject shortcut is pressed (&lt;span style=&quot; font-weight:600;&quot;&gt;XF86Eject&lt;/span&gt; by default)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Активирај следећу радњу када се притисне пречица за избацивање (&lt;span style=&quot; font-weight:600;&quot;&gt;XF86Eject&lt;/span&gt; by default)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
         <location filename="../configuration.ui" line="45"/>
         <source>When eject button is pressed:</source>
-        <translation type="unfinished"></translation>
+        <translation>Када је дугме за избацивање притиснуто:</translation>
     </message>
     <message>
         <location filename="../configuration.cpp" line="44"/>
         <source>Popup menu</source>
-        <translation type="unfinished">прикажи мени</translation>
+        <translation>Прикажи мени</translation>
     </message>
     <message>
         <location filename="../configuration.cpp" line="45"/>
         <source>Show info</source>
-        <translation type="unfinished">прикажи инфо</translation>
+        <translation>Прикажи инфо</translation>
     </message>
     <message>
         <location filename="../configuration.cpp" line="46"/>
         <location filename="../configuration.cpp" line="51"/>
         <source>Do nothing</source>
-        <translation type="unfinished">не ради ништа</translation>
+        <translation>Не ради ништа</translation>
     </message>
     <message>
         <location filename="../configuration.cpp" line="52"/>
         <source>Eject All Optical Drives</source>
-        <translation type="unfinished"></translation>
+        <translation>Избаци све оптичке уређаје</translation>
     </message>
 </context>
 <context>
@@ -63,17 +63,17 @@
     <message>
         <location filename="../actions/deviceaction_info.cpp" line="40"/>
         <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
-        <translation type="unfinished">Уређај &lt;b&gt;&lt;nobr&gt;„%1“&lt;/nobr&gt;&lt;/b&gt; је прикључен.</translation>
+        <translation>Уређај &lt;b&gt;&lt;nobr&gt;„%1“&lt;/nobr&gt;&lt;/b&gt; је прикључен.</translation>
     </message>
     <message>
         <location filename="../actions/deviceaction_info.cpp" line="45"/>
         <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
-        <translation type="unfinished">Уређај &lt;b&gt;&lt;nobr&gt;„%1“&lt;/nobr&gt;&lt;/b&gt; је уклоњен.</translation>
+        <translation>Уређај &lt;b&gt;&lt;nobr&gt;„%1“&lt;/nobr&gt;&lt;/b&gt; је уклоњен.</translation>
     </message>
     <message>
         <location filename="../actions/deviceaction_info.cpp" line="50"/>
         <source>Removable media/devices manager</source>
-        <translation type="unfinished">Менаџер уклоњивих медија/уређаја</translation>
+        <translation>Менаџер уклоњивих медија/уређаја</translation>
     </message>
 </context>
 <context>
@@ -81,12 +81,12 @@
     <message>
         <location filename="../actions/ejectaction_optical.cpp" line="59"/>
         <source>Removable media/devices manager</source>
-        <translation type="unfinished">Менаџер уклоњивих медија/уређаја</translation>
+        <translation>Менаџер уклоњивих медија/уређаја</translation>
     </message>
     <message>
         <location filename="../actions/ejectaction_optical.cpp" line="59"/>
         <source>Ejected all optical drives</source>
-        <translation type="unfinished"></translation>
+        <translation>Избаци све оптичке уређаје</translation>
     </message>
 </context>
 <context>
@@ -94,12 +94,12 @@
     <message>
         <location filename="../lxqtmountplugin.cpp" line="79"/>
         <source>Removable media/devices manager: Global shortcut &apos;%1&apos; cannot be registered</source>
-        <translation type="unfinished"></translation>
+        <translation>Менаџер уклоњивих медија/уређаја: Глобална пречица &apos;%1&apos; не може бити регистрована</translation>
     </message>
     <message>
         <location filename="../lxqtmountplugin.cpp" line="116"/>
         <source>Eject removable media</source>
-        <translation type="unfinished"></translation>
+        <translation>Избаци уклоњиви медиј</translation>
     </message>
 </context>
 <context>
@@ -107,18 +107,18 @@
     <message>
         <location filename="../menudiskitem.cpp" line="153"/>
         <source>Mounting of &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; failed: %2</source>
-        <translation type="unfinished"></translation>
+        <translation>Повезивање &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; није успело: %2</translation>
     </message>
     <message>
         <location filename="../menudiskitem.cpp" line="155"/>
         <location filename="../menudiskitem.cpp" line="176"/>
         <source>Removable media/devices manager</source>
-        <translation type="unfinished">Менаџер уклоњивих медија/уређаја</translation>
+        <translation>Менаџер уклоњивих медија/уређаја</translation>
     </message>
     <message>
         <location filename="../menudiskitem.cpp" line="174"/>
         <source>Unmounting of &lt;strong&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/strong&gt; failed: %2</source>
-        <translation type="unfinished"></translation>
+        <translation>Уклањање &lt;strong&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/strong&gt; није успело: %2</translation>
     </message>
 </context>
 <context>
@@ -126,7 +126,7 @@
     <message>
         <location filename="../popup.cpp" line="68"/>
         <source>No devices are available</source>
-        <translation type="unfinished"></translation>
+        <translation>Нема доступних уређаја</translation>
     </message>
 </context>
 </TS>
