@@ -4,19 +4,19 @@
 <context>
     <name>ShowDesktop</name>
     <message>
-        <location filename="../showdesktop.cpp" line="48"/>
+        <location filename="../showdesktop.cpp" line="44"/>
         <source>Show desktop</source>
-        <translation type="unfinished"></translation>
+        <translation>اعرض سطح المكتب</translation>
     </message>
     <message>
-        <location filename="../showdesktop.cpp" line="58"/>
+        <location filename="../showdesktop.cpp" line="66"/>
         <source>Show Desktop: Global shortcut &apos;%1&apos; cannot be registered</source>
-        <translation>إظهار سطح المكتب: ﻻ يمكن تسجيل اختصار لوحة المفاتيح العامُّ `%1`</translation>
+        <translation>عرض سطح المكتب: تعذر تسجيل الاختصار العمومي ”%1“</translation>
     </message>
     <message>
-        <location filename="../showdesktop.cpp" line="63"/>
+        <location filename="../showdesktop.cpp" line="51"/>
         <source>Show Desktop</source>
-        <translation>إظهار سطح المكتب</translation>
+        <translation>اعرض سطح المكتب</translation>
     </message>
 </context>
 </TS>
