@@ -6,17 +6,17 @@
     <message>
         <location filename="../showdesktop.cpp" line="44"/>
         <source>Show desktop</source>
-        <translation>Toon bureaublad</translation>
+        <translation>Bureaublad tonen</translation>
     </message>
     <message>
         <location filename="../showdesktop.cpp" line="66"/>
         <source>Show Desktop: Global shortcut &apos;%1&apos; cannot be registered</source>
-        <translation>Bureaublad weergeven: systeembrede sneltoets &apos;%1&apos; kan niet worden geregistreerd</translation>
+        <translation>Bureaublad tonen: de algemene sneltoets &apos;%1&apos; kan niet worden vastgelegd</translation>
     </message>
     <message>
         <location filename="../showdesktop.cpp" line="51"/>
         <source>Show Desktop</source>
-        <translation>Toon bureaublad</translation>
+        <translation>Bureaublad tonen</translation>
     </message>
 </context>
 </TS>
