@@ -4,17 +4,17 @@
 <context>
     <name>ShowDesktop</name>
     <message>
-        <location filename="../showdesktop.cpp" line="48"/>
+        <location filename="../showdesktop.cpp" line="44"/>
         <source>Show desktop</source>
-        <translation type="unfinished"></translation>
+        <translation>Masaüstünü göster</translation>
     </message>
     <message>
-        <location filename="../showdesktop.cpp" line="69"/>
+        <location filename="../showdesktop.cpp" line="66"/>
         <source>Show Desktop: Global shortcut &apos;%1&apos; cannot be registered</source>
         <translation>Masaüstünü Göster: &apos;%1&apos; genel kısayolu kaydedilemiyor</translation>
     </message>
     <message>
-        <location filename="../showdesktop.cpp" line="55"/>
+        <location filename="../showdesktop.cpp" line="51"/>
         <source>Show Desktop</source>
         <translation>Masaüstünü Göster</translation>
     </message>
