@@ -73,13 +73,14 @@ void VolumeButton::setMuteOnMiddleClick(bool state)
 
 void VolumeButton::setMixerCommand(const QString &command)
 {
-    m_mixerCommand = command;
+    m_mixerParams = QProcess::splitCommand(command);
+    m_mixerCommand = m_mixerParams.empty() ? QString{} : m_mixerParams.takeFirst();
 }
 
 void VolumeButton::enterEvent(QEvent *event)
 {
     // show tooltip immediately on entering widget
-    QToolTip::showText(static_cast<QEnterEvent*>(event)->globalPos(), toolTip());
+    QToolTip::showText(static_cast<QEnterEvent*>(event)->globalPos(), toolTip(), this);
 }
 
 void VolumeButton::mouseMoveEvent(QMouseEvent *event)
@@ -87,7 +88,7 @@ void VolumeButton::mouseMoveEvent(QMouseEvent *event)
     QToolButton::mouseMoveEvent(event);
     // show tooltip immediately on moving the mouse
     if (!QToolTip::isVisible()) // prevent sliding of tooltip
-        QToolTip::showText(event->globalPos(), toolTip());
+        QToolTip::showText(event->globalPos(), toolTip(), this);
 }
 
 void VolumeButton::wheelEvent(QWheelEvent *event)
@@ -97,7 +98,7 @@ void VolumeButton::wheelEvent(QWheelEvent *event)
 
 void VolumeButton::mouseReleaseEvent(QMouseEvent *event)
 {
-    if (event->button() == Qt::MidButton && m_muteOnMiddleClick) {
+    if (event->button() == Qt::MiddleButton && m_muteOnMiddleClick) {
         if (m_volumePopup->device()) {
             m_volumePopup->device()->toggleMute();
             return;
@@ -140,7 +141,7 @@ void VolumeButton::hideVolumeSlider()
 
 void VolumeButton::handleMixerLaunch()
 {
-    QProcess::startDetached(m_mixerCommand, QStringList());
+    QProcess::startDetached(m_mixerCommand, m_mixerParams);
 }
 
 void VolumeButton::handleStockIconChanged(const QString &iconName)
